/* This file is part of the Zenipex Library.
* Copyleft (C) 2011 Mitchell Keith Bloch a.k.a. bazald
*
* This source file is simply under the public domain.
*/

#ifndef TUTORIAL_STATE_H
#define TUTORIAL_STATE_H

#include <Zeni/Game.h>
#include <Zeni/Timer.h>
#include <Zeni/Video.h>
#include <Zeni/Vector3f.h>

class Tutorial_State : public Zeni::Gamestate_Base {
  struct Screen_Rectangle {
    Screen_Rectangle()
      : position(100.0f, 100.0f), 
      size(200.0f, 100.0f, 0.0f), 
      max_velocity(200.0f, 150.0f, 0.0f)
    {
    }

    Zeni::Point2f position;
    Zeni::Vector3f size;

    Zeni::Vector3f max_velocity;
  } m_rect;

  struct Controls {
    Controls() : left(false), right(false), up(false), down(false) {}

    bool left;
    bool right;
    bool up;
    bool down;
  } m_controls;

public:
  Tutorial_State();

private:
  void on_push();
  void on_pop();
  void on_cover();
  
  void on_controller_axis(const SDL_ControllerAxisEvent &event);
  void on_controller_button(const SDL_ControllerButtonEvent &event);
  void on_key(const SDL_KeyboardEvent &event);

  void perform_logic();
  void step(const float &time_step);

  void render();

  Zeni::Time m_current_time;
  float m_time_passed;
  float m_max_time_step;  //< Optional
  float m_max_time_steps; //< Optional
};

#endif
